Index: trunk/SophyaExt/XephemAstroLib/Makefile.bak
===================================================================
--- trunk/SophyaExt/XephemAstroLib/Makefile.bak	(revision 1719)
+++ trunk/SophyaExt/XephemAstroLib/Makefile.bak	(revision 1719)
@@ -0,0 +1,64 @@
+# Makefile for the basic astronomy routines.
+# The idea is to compile and archive them into libastro.a
+
+# flags assume gcc
+CFLAGS= -O2 -ffast-math -Wall
+CC = cc
+
+OBJS =	\
+	aa_hadec.o \
+	aberration.o \
+	actan.o \
+	airmass.o \
+	anomaly.o \
+	ap_as.o \
+	auxil.o \
+	chap95.o \
+	chap95_data.o \
+	circum.o \
+	comet.o \
+	dbfmt.o \
+	deep.o \
+	deltat.o \
+	earthsat.o \
+	eq_ecl.o \
+	eq_gal.o \
+	formats.o \
+	helio.o \
+	libration.o \
+	misc.o \
+	mjd.o \
+	moon.o \
+	mooncolong.o \
+	nutation.o \
+	obliq.o \
+	parallax.o \
+	plans.o \
+	precess.o \
+	reduce.o \
+	refract.o \
+	rings.o \
+	riset.o \
+	riset_cir.o \
+	sdp4.o \
+	sgp4.o \
+	sphcart.o \
+	sun.o \
+	thetag.o \
+	utc_gst.o \
+	twobody.o \
+	vsop87.o \
+	vsop87_data.o
+
+libastro.a:	$(OBJS)
+	ar rv $@ $?
+	ranlib $@
+
+libastro.so:    $(OBJS)
+	$(CC) -shared -o $@ $(OBJS)
+
+clobber:
+	rm -f *.o libastro.a
+
+# For RCS Only -- Do Not Edit
+# @(#) $RCSfile: Makefile.bak,v $ $Date: 2001-10-22 12:08:25 $ $Revision: 1.1 $ $Name: not supported by cvs2svn $
Index: trunk/SophyaExt/XephemAstroLib/P_.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/P_.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/P_.h	(revision 1719)
@@ -11,4 +11,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: P_.h,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: P_.h,v $ $Date: 2001-10-22 12:08:25 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/README
===================================================================
--- trunk/SophyaExt/XephemAstroLib/README	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/README	(revision 1719)
@@ -19,3 +19,3 @@
 
 ! For RCS Only -- Do Not Edit
-! @(#) $RCSfile: README,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+! @(#) $RCSfile: README,v $ $Date: 2001-10-22 12:08:25 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
Index: trunk/SophyaExt/XephemAstroLib/aa_hadec.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/aa_hadec.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/aa_hadec.c	(revision 1719)
@@ -76,3 +76,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: aa_hadec.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: aa_hadec.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/aberration.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/aberration.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/aberration.c	(revision 1719)
@@ -134,3 +134,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: aberration.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: aberration.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/actan.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/actan.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/actan.c	(revision 1719)
@@ -1,5 +1,11 @@
 #include <math.h>
 
-/* @(#) $Id: actan.c,v 1.1.1.1 2001-04-10 14:40:45 cmv Exp $ */
+/* @(#) $Id: actan.c,v 1.2 2001-10-22 12:08:26 cmv Exp $ */
+
+/* commonly in math.h, but not in strict ANSI C */
+#ifndef M_PI
+#define M_PI            3.14159265358979323846
+#define M_PI_2          1.57079632679489661923
+#endif
 
 double
@@ -59,3 +65,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: actan.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: actan.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/airmass.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/airmass.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/airmass.c	(revision 1719)
@@ -25,3 +25,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: airmass.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: airmass.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/anomaly.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/anomaly.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/anomaly.c	(revision 1719)
@@ -64,3 +64,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: anomaly.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: anomaly.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/ap_as.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/ap_as.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/ap_as.c	(revision 1719)
@@ -28,8 +28,8 @@
 	obj_cir (&n, &o);
 	*rap -= o.s_ra - *rap;
+	*decp -= o.s_dec - *decp;
+	if (*decp >  PI/2) {*decp =  PI - *decp; *rap += PI; }
+	if (*decp < -PI/2) {*decp = -PI - *decp; *rap += PI; }
 	range (rap, 2*PI);
-	*decp -= o.s_dec - *decp;
-	if (*decp >  PI/2) *decp =  PI - *decp;
-	if (*decp < -PI/2) *decp = -PI - *decp;
 	precess (mjd, Mjd, rap, decp);
 }
@@ -60,3 +60,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: ap_as.c,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: ap_as.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/astro.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/astro.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/astro.h	(revision 1719)
@@ -163,4 +163,8 @@
 extern void refract P_((double pr, double tr, double ta, double *aa));
 
+/* rings.c */
+extern void satrings P_((double sb, double sl, double sr, double el, double er,
+    double JD, double *etiltp, double *stiltp));
+
 /* riset.c */
 extern void riset P_((double ra, double dec, double lat, double dis,
@@ -176,4 +180,7 @@
 extern void sunpos P_((double mjd, double *lsn, double *rsn, double *bsn));
 
+/* twobody.c */
+extern void vrc P_((double *v, double *r, double tp, double e, double q));
+
 /* utc_gst.c */
 extern void utc_gst P_((double mjd, double utc, double *gst));
@@ -184,4 +191,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: astro.h,v $ $Date: 2001-04-10 14:40:45 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: astro.h,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/auxil.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/auxil.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/auxil.c	(revision 1719)
@@ -15,5 +15,5 @@
 static int prefs[NPREFS] = {
     PREF_TOPO, PREF_METRIC, PREF_MDY, PREF_UTCTZ, PREF_HIPREC, PREF_NOMSGBELL,
-    PREF_PREFILL, PREF_TIPSON, PREF_CONFIRMON
+    PREF_PREFILL, PREF_TIPSON, PREF_CONFIRMON, PREF_WEEKSTART
 };
 
@@ -48,3 +48,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: auxil.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: auxil.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/chap95.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/chap95.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/chap95.c	(revision 1719)
@@ -178,3 +178,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: chap95.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: chap95.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/chap95.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/chap95.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/chap95.h	(revision 1719)
@@ -66,4 +66,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: chap95.h,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: chap95.h,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/chap95_data.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/chap95_data.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/chap95_data.c	(revision 1719)
@@ -781,3 +781,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: chap95_data.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: chap95_data.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/circum.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/circum.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/circum.c	(revision 1719)
@@ -67,5 +67,4 @@
 	double lam, bet;	/* geocentric ecliptic long and lat */
 	double dia, mag;	/* angular diameter at 1 AU and magnitude */
-	double f;		/* fractional phase from earth */
 	int p;
 
@@ -84,5 +83,5 @@
 	sunpos (mjed, &lsn, &rsn, 0);
 
-	/* find helio long/lat; sun/planet and earth/plant dist; ecliptic
+	/* find helio long/lat; sun/planet and earth/planet dist; ecliptic
 	 * long/lat; diameter and mag.
 	 */
@@ -92,7 +91,6 @@
 	cir_sky (np, lpd, psi, rp, &rho, lam, bet, lsn, rsn, op);
 
-	/* compute magnitude and angular size */
-	f = op->s_phase ? 5*log10(rp*rho) - 5*log10(op->s_phase/100) : 100;
-	set_smag (op, mag+f);
+	/* set magnitude and angular size */
+	set_smag (op, mag);
 	op->s_size = (float)(dia/rho);
 
@@ -129,8 +127,8 @@
 	ra = op->f_RA;
 	dec = op->f_dec;
-	precess (op->f_epoch, mjd, &ra, &dec);
+	precess (op->f_epoch, mjed, &ra, &dec);
 
 	/* convert equatoreal ra/dec to mean geocentric ecliptic lat/long */
-	eq_ecl (mjd, ra, dec, &bet, &lam);
+	eq_ecl (mjed, ra, dec, &bet, &lam);
 
 	/* find solar ecliptical long.(mean equinox) and distance from earth */
@@ -138,5 +136,5 @@
 
 	/* allow for relativistic light bending near the sun */
-	deflect (mjd, lam, bet, lsn, rsn, 1e10, &ra, &dec);
+	deflect (mjed, lam, bet, lsn, rsn, 1e10, &ra, &dec);
 
 	/* TODO: correction for annual parallax would go here */
@@ -145,6 +143,6 @@
 	 * geocentric
 	 */
-	nut_eq(mjd, &ra, &dec);
-	ab_eq(mjd, lsn, &ra, &dec);
+	nut_eq(mjed, &ra, &dec);
+	ab_eq(mjed, lsn, &ra, &dec);
 	op->s_gaera = (float)ra;
 	op->s_gaedec = (float)dec;
@@ -193,6 +191,5 @@
 	double dt;		/* light travel time to object */
 	double lg;		/* helio long of earth */
-	double nu, ea;		/* true anomaly and eccentric anomaly */
-	double ma;		/* mean anomaly */
+	double nu;		/* true anomaly */
 	double rp=0;		/* distance from the sun */
 	double lo, slo, clo;	/* angle from ascending node */
@@ -206,8 +203,8 @@
 	double lam;    		/* geocentric ecliptic longitude */
 	double bet;    		/* geocentric ecliptic latitude */
-	double e;		/* fast eccentricity */
 	double ll=0, sll, cll;	/* helio angle between object and earth */
 	double mag;		/* magnitude */
 	double e_n;		/* mean daily motion */
+	double tp;		/* time from perihelion (days) */
 	double rpd=0;
 	double y;
@@ -217,7 +214,4 @@
 	sunpos (mjed, &lsn, &rsn, 0);
 	lg = lsn + PI;
-
-	/* faster access to eccentricty */
-	e = op->e_e;
 
 	/* mean daily motion is derived fro mean distance */
@@ -235,7 +229,7 @@
 					&inc, &om, &Om);
 
-	    ma = degrad (op->e_M + (mjed - op->e_cepoch - dt) * e_n);
-	    anomaly (ma, e, &nu, &ea);
-	    rp = op->e_a * (1-e*e) / (1+e*cos(nu));
+	    tp = mjed - dt - (op->e_cepoch - op->e_M/e_n);
+	    vrc (&nu, &rp, tp, op->e_e, op->e_a*(1-op->e_e));
+	    nu = degrad(nu);
 	    lo = nu + om;
 	    slo = sin(lo);
@@ -301,6 +295,5 @@
 	double dt;		/* light travel time to object */
 	double lg;		/* helio long of earth */
-	double nu, ea;		/* true anomaly and eccentric anomaly */
-	double ma;		/* mean anomaly */
+	double nu;		/* true anomaly and eccentric anomaly */
 	double rp=0;		/* distance from the sun */
 	double lo, slo, clo;	/* angle from ascending node */
@@ -319,4 +312,5 @@
 	double mag;		/* magnitude */
 	double a;		/* mean distance */
+	double tp;		/* time from perihelion (days) */
 	double rpd=0;
 	double y;
@@ -342,7 +336,7 @@
 			    &inc, &om, &Om);
 
-	    ma = degrad ((mjed - op->h_ep - dt) * n);
-	    anomaly (ma, e, &nu, &ea);
-	    rp = a * (e*e-1.0) / (1.0+e*cos(nu));
+	    tp = mjed - dt - op->h_ep;
+	    vrc (&nu, &rp, tp, op->h_e, op->h_qp);
+	    nu = degrad(nu);
 	    lo = nu + om;
 	    slo = sin(lo);
@@ -581,5 +575,5 @@
 
 	/* convert to equatoreal [mean equator, with mean obliquity] */
-	ecl_eq (mjd, bet, lam, &ra, &dec);
+	ecl_eq (mjed, bet, lam, &ra, &dec);
 	tra = ra;	/* keep mean coordinates */
 	tdec = dec;
@@ -592,10 +586,10 @@
 	 */
 	if (!is_planet(op,SUN) && !is_planet(op,MOON))
-	    deflect (mjd, op->s_hlong, op->s_hlat, lsn, rsn, *rho, &ra, &dec);
+	    deflect (mjed, op->s_hlong, op->s_hlat, lsn, rsn, *rho, &ra, &dec);
 
 	/* correct ra/dec to form geocentric apparent */
-	nut_eq (mjd, &ra, &dec);
+	nut_eq (mjed, &ra, &dec);
 	if (!is_planet(op,MOON))
-	    ab_eq (mjd, lsn, &ra, &dec);
+	    ab_eq (mjed, lsn, &ra, &dec);
 	op->s_gaera = (float)ra;
 	op->s_gaedec = (float)dec;
@@ -635,5 +629,5 @@
 	    ra = tra + dra;
 	    dec = tdec + ddec;
-	    precess (mjd, epoch, &ra, &dec);
+	    precess (mjed, epoch, &ra, &dec);
 	}
 	range(&ra, 2*PI);
@@ -755,3 +749,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: circum.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: circum.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/circum.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/circum.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/circum.h	(revision 1719)
@@ -68,5 +68,5 @@
 
 /* longest object name, including trailing '\0' */
-#define	MAXNM	14
+#define	MAXNM	22
 
 /* Obj is a massive union.
@@ -156,7 +156,7 @@
     float  eo_om;	/* argument of perihelion, degress */
     float  eo_a;	/* mean distance, aka,semi-maj axis,AU */
-    float  eo_e;	/* eccentricity */
     float  eo_M;	/* mean anomaly, ie, degrees from perihelion at cepoch*/
     float  eo_size;	/* angular size, in arc seconds at 1 AU */
+    double eo_e;	/* eccentricity (double for when near 1 computing q) */
     double eo_cepoch;	/* epoch date (M reference), as an mjd */
     double eo_epoch;	/* equinox year (inc/Om/om reference), as an mjd. */
@@ -440,4 +440,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: circum.h,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
- */
+ * @(#) $RCSfile: circum.h,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
+ */
Index: trunk/SophyaExt/XephemAstroLib/comet.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/comet.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/comet.c	(revision 1719)
@@ -84,3 +84,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: comet.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: comet.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/compare_with_xephem.csh
===================================================================
--- trunk/SophyaExt/XephemAstroLib/compare_with_xephem.csh	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/compare_with_xephem.csh	(revision 1719)
@@ -4,15 +4,28 @@
 
 set dir = $DPCSOURCE/XephemAstroLib/
+set log = `pwd`/compare.log
 
-rm -f compare.log; touch compare.log
+rm -f $log; touch $log
 
+echo ======================= NOUVEAU REPERTOIRE >>& $log
+ls *.h >>& $log
+ls *.c >>& $log
+
+echo ======================= REPERTOIRE $dir >>& $log
+pushd $dir
+ls *.h  >>& $log
+ls *.c >>& $log
+popd
+
+echo ======================= INCLUDE >>& $log
 foreach f ( *.h )
-  echo ======================= $f >> compare.log
-  diff $f $dir/$f >> compare.log
+  echo ======================= $f >>& $log
+  diff $f $dir/$f >>& $log
 end
 
+echo ======================= FICHIERS >>& $log
 foreach f ( *.c )
-  echo ======================= $f >> compare.log
-  diff $f $dir/$f >> compare.log
+  echo ======================= $f >>& $log
+  diff $f $dir/$f >>& $log
 end
 
Index: trunk/SophyaExt/XephemAstroLib/dbfmt.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/dbfmt.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/dbfmt.c	(revision 1719)
@@ -510,5 +510,5 @@
 	    break;
 	case E_E:
-	    op->e_e = (float) atod (bp);
+	    op->e_e = atod (bp);
 	    break;
 	case E_M:
@@ -1014,3 +1014,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbfmt.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbfmt.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/deep.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/deep.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/deep.c	(revision 1719)
@@ -788,3 +788,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: deep.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: deep.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/deepconst.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/deepconst.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/deepconst.h	(revision 1719)
@@ -2,5 +2,5 @@
 #define _CONST_H
 
-/* $Id: deepconst.h,v 1.1.1.1 2001-04-10 14:40:46 cmv Exp $ */
+/* $Id: deepconst.h,v 1.2 2001-10-22 12:08:26 cmv Exp $ */
 
 
@@ -31,4 +31,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: deepconst.h,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: deepconst.h,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/deltat.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/deltat.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/deltat.c	(revision 1719)
@@ -305,3 +305,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: deltat.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: deltat.c,v $ $Date: 2001-10-22 12:08:26 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/earthsat.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/earthsat.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/earthsat.c	(revision 1719)
@@ -797,3 +797,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: earthsat.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: earthsat.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/eq_ecl.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/eq_ecl.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/eq_ecl.c	(revision 1719)
@@ -51,5 +51,5 @@
 	static double lastmjd = -10000;	/* last mjd calculated */
 	static double seps, ceps;	/* sin and cos of mean obliquity */
-	double sx, cx, sy, cy, ty;
+	double sx, cx, sy, cy, ty, sq;
 
 	if (mjd != lastmjd) {
@@ -67,7 +67,8 @@
 	cx = cos(x);
 	sx = sin(x);
-        /* modifs CMV *q = asin((sy*ceps)-(cy*seps*sx*sw)); */
-        *q = (sy*ceps)-(cy*seps*sx*sw);
-        if(*q<-1.) *q = -PI/2.; else if(*q>1.) *q = PI/2.; else *q = asin(*q);
+        sq = (sy*ceps)-(cy*seps*sx*sw);
+	if (sq < -1) sq = -1;
+	if (sq >  1) sq =  1;
+        *q = asin(sq);
         *p = atan(((sx*ceps)+(ty*seps*sw))/cx);
         if (cx<0) *p += PI;		/* account for atan quad ambiguity */
@@ -76,3 +77,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: eq_ecl.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: eq_ecl.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/eq_gal.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/eq_gal.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/eq_gal.c	(revision 1719)
@@ -102,3 +102,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: eq_gal.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: eq_gal.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/formats.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/formats.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/formats.c	(revision 1719)
@@ -305,3 +305,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: formats.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: formats.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/helio.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/helio.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/helio.c	(revision 1719)
@@ -52,3 +52,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: helio.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: helio.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/libration.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/libration.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/libration.c	(revision 1719)
@@ -2228,3 +2228,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: libration.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: libration.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/misc.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/misc.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/misc.c	(revision 1719)
@@ -473,3 +473,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: misc.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: misc.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/mjd.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/mjd.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/mjd.c	(revision 1719)
@@ -261,3 +261,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mjd.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mjd.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/moon.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/moon.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/moon.c	(revision 1719)
@@ -3485,3 +3485,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: moon.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: moon.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/mooncolong.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/mooncolong.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/mooncolong.c	(revision 1719)
@@ -262,3 +262,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mooncolong.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mooncolong.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/nutation.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/nutation.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/nutation.c	(revision 1719)
@@ -440,3 +440,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: nutation.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: nutation.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/obliq.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/obliq.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/obliq.c	(revision 1719)
@@ -28,3 +28,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: obliq.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: obliq.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/parallax.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/parallax.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/parallax.c	(revision 1719)
@@ -42,3 +42,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: parallax.c,v $ $Date: 2001-04-10 14:40:46 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: parallax.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/precess.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/precess.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/precess.c	(revision 1719)
@@ -146,3 +146,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: precess.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: precess.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/preferences.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/preferences.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/preferences.h	(revision 1719)
@@ -7,6 +7,6 @@
 
 typedef enum {
-    PREF_EQUATORIAL, PREF_UNITS, PREF_DATE_FORMAT, PREF_ZONE,
-    PREF_DPYPREC, PREF_MSG_BELL, PREF_PRE_FILL, PREF_TIPS, PREF_CONFIRM,
+    PREF_EQUATORIAL, PREF_UNITS, PREF_DATE_FORMAT, PREF_ZONE, PREF_DPYPREC,
+    PREF_MSG_BELL, PREF_PRE_FILL, PREF_TIPS, PREF_CONFIRM, PREF_WEEKSTART,
     NPREFS
 } Preferences;
@@ -21,4 +21,5 @@
 typedef enum {PREF_TIPSON, PREF_NOTIPS} PrefTips;
 typedef enum {PREF_CONFIRMON, PREF_NOCONFIRM} PrefConfirm;
+typedef enum {PREF_SAT, PREF_SUN, PREF_MON} PrefWeekStart;
 
 extern int pref_get P_((Preferences p));
@@ -28,4 +29,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: preferences.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: preferences.h,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/reduce.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/reduce.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/reduce.c	(revision 1719)
@@ -75,3 +75,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: reduce.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: reduce.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/refract.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/refract.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/refract.c	(revision 1719)
@@ -32,5 +32,4 @@
 	    *ta = taLT + (taGE - taLT)*p;
 	}
-	    
 }
 
@@ -60,5 +59,5 @@
 	r = degrad(a/b);
 
-	*ta  =  aa - r;
+	*ta  =  (aa < 0 && r < 0) ? aa : aa - r;	/* 0 below ~5 degs */
 }
 
@@ -101,3 +100,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: refract.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: refract.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/rings.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/rings.c	(revision 1719)
+++ trunk/SophyaExt/XephemAstroLib/rings.c	(revision 1719)
@@ -0,0 +1,46 @@
+#include <stdio.h>
+#include <math.h>
+#if defined(__STDC__)
+#include <stdlib.h>
+#endif
+
+#include "P_.h"
+#include "astro.h"
+#include "circum.h"
+
+/*  RINGS OF SATURN by Olson, et al, BASIC Code from Sky & Telescope, May 1995.
+ *  As converted from BASIC to C by pmartz@dsd.es.com (Paul Martz)
+ *  Adapted to xephem by Elwood Charles Downey.
+ */
+void
+satrings (sb, sl, sr, el, er, JD, etiltp, stiltp)
+double sb, sl, sr;		/* Saturn hlat, hlong, sun dist */
+double el, er;			/* Earth hlong, sun dist */
+double JD;			/* Julian date */
+double *etiltp, *stiltp;	/* tilt from earth and sun, rads southward */
+{
+	double t, i, om;
+	double x, y, z;
+	double la, be;
+	double s, b, sp, bp;
+
+	t = (JD-2451545.)/365250.;
+	i = degrad(28.04922-.13*t+.0004*t*t);
+	om = degrad(169.53+13.826*t+.04*t*t);
+
+	x = sr*cos(sb)*cos(sl)-er*cos(el);
+	y = sr*cos(sb)*sin(sl)-er*sin(el);
+	z = sr*sin(sb);
+
+	la = atan(y/x);
+	if (x<0) la+=PI;
+	be = atan(z/sqrt(x*x+y*y));
+
+	s = sin(i)*cos(be)*sin(la-om)-cos(i)*sin(be);
+	b = atan(s/sqrt(1.-s*s));
+	sp = sin(i)*cos(sb)*sin(sl-om)-cos(i)*sin(sb);
+	bp = atan(sp/sqrt(1.-sp*sp));
+
+	*etiltp = b;
+	*stiltp = bp;
+}
Index: trunk/SophyaExt/XephemAstroLib/riset.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/riset.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/riset.c	(revision 1719)
@@ -103,3 +103,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: riset.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: riset.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/riset_cir.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/riset_cir.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/riset_cir.c	(revision 1719)
@@ -385,3 +385,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: riset_cir.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: riset_cir.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/satlib.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/satlib.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/satlib.h	(revision 1719)
@@ -2,5 +2,5 @@
 #define __SATLIB_H
 
-/* $Id: satlib.h,v 1.1.1.1 2001-04-10 14:40:47 cmv Exp $ */
+/* $Id: satlib.h,v 1.2 2001-10-22 12:08:28 cmv Exp $ */
 
 typedef struct _SatElem {
@@ -203,4 +203,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: satlib.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: satlib.h,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/satspec.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/satspec.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/satspec.h	(revision 1719)
@@ -2,5 +2,5 @@
 #define __SATSPEC_H
 
-/* $Id: satspec.h,v 1.1.1.1 2001-04-10 14:40:47 cmv Exp $ */
+/* $Id: satspec.h,v 1.2 2001-10-22 12:08:28 cmv Exp $ */
 
 #include "sattypes.h"
@@ -40,4 +40,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: satspec.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: satspec.h,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/sattypes.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/sattypes.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/sattypes.h	(revision 1719)
@@ -2,5 +2,5 @@
 #define __SATTYPES_H
 
-/* $Id: sattypes.h,v 1.1.1.1 2001-04-10 14:40:47 cmv Exp $ */
+/* $Id: sattypes.h,v 1.2 2001-10-22 12:08:28 cmv Exp $ */
 
 typedef struct _Vec3 {
@@ -25,4 +25,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: sattypes.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: sattypes.h,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/sdp4.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/sdp4.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/sdp4.c	(revision 1719)
@@ -110,8 +110,8 @@
     /* private temporary variables */
     double A,AXN,AYN,AYNL,BETA,BETAL,CAPU,COS2U,COSEPW,
-	COSIK,COSNOK,COSU,COSUK,E,ECOSE,ELSQ,EM,EPW,ESINE,OMGADF,PL,
+	COSIK,COSNOK,COSU,COSUK,E,ECOSE,ELSQ,EM=0,EPW,ESINE,OMGADF,PL,
 	R,RDOT,RDOTK,RFDOT,RFDOTK,RK,SIN2U,SINEPW,SINIK,SINNOK,
 	SINU,SINUK,TEMP,TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,TEMP6,TEMPA,
-	TEMPE,TEMPL,TSQ,U,UK,UX,UY,UZ,VX,VY,VZ,XINC,XINCK,XL,XLL,XLT,
+	TEMPE,TEMPL,TSQ,U,UK,UX,UY,UZ,VX,VY,VZ,XINC=0,XINCK,XL,XLL,XLT,
 	XMAM,XMDF,XMX,XMY,XN,XNODDF,XNODE,XNODEK;
 
@@ -432,3 +432,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sdp4.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sdp4.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/sgp4.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/sgp4.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/sgp4.c	(revision 1719)
@@ -403,3 +403,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sgp4.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sgp4.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/sphcart.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/sphcart.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/sphcart.c	(revision 1719)
@@ -40,3 +40,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sphcart.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sphcart.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/sun.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/sun.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/sun.c	(revision 1719)
@@ -45,3 +45,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sun.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: sun.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/thetag.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/thetag.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/thetag.c	(revision 1719)
@@ -3,5 +3,5 @@
 #include "deepconst.h"
 
-/* @(#) $Id: thetag.c,v 1.1.1.1 2001-04-10 14:40:47 cmv Exp $ */
+/* @(#) $Id: thetag.c,v 1.2 2001-10-22 12:08:28 cmv Exp $ */
 
 
@@ -88,3 +88,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: thetag.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: thetag.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/twobody.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/twobody.c	(revision 1719)
+++ trunk/SophyaExt/XephemAstroLib/twobody.c	(revision 1719)
@@ -0,0 +1,238 @@
+/*
+ *
+ * TWOBODY.C
+ *
+ *  Computation of planetary position, two-body computation
+ *
+ *  Paul Schlyter, 1987-06-15
+ *
+ *  Decreased EPSILON from 2E-4 to 3E-8,  1988-12-05
+ *
+ *  1990-01-01:  Bug fix in almost parabolic orbits: now the routine
+ *       doesn't bomb there (an if block was too large)
+ *
+ *  2000-12-06:  Donated to Elwood Downey if he wants to use it in XEphem
+ */
+ 
+ 
+#include <stdio.h>
+#include <stdlib.h>
+#include <math.h>
+ 
+ 
+/* Constants used when solving Kepler's equation */
+#define EPSILON   3E-8
+#define INFINITY  1E+10
+ 
+/* Math constants */
+#define PI      3.14159265358979323846
+#define RADEG   ( 180.0 / PI )
+#define DEGRAD  ( PI / 180.0 )
+ 
+/* Trig functions in degrees */
+#define sind(x)      sin(x*DEGRAD)
+#define cosd(x)      cos(x*DEGRAD)
+#define atand(x)     (RADEG*atan(x))
+#define atan2d(y,x)  (RADEG*atan2(y,x))
+ 
+/* Gauss' grav.-konstant */
+#define K    1.720209895E-2
+#define KD   ( K * 180.0 / PI )
+#define K2   ( K / 2.0 )
+ 
+ 
+ 
+ 
+static double cubroot( double x )
+/* Cubic root */
+{
+    double a,b;
+ 
+    if ( x == 0.0 )
+        return  0.0;
+    else
+    {
+        a = fabs(x);
+        b = exp( log(a) / 3.0 );
+        return  x > 0.0 ? b : -b;
+    }
+}  /* cubroot */
+ 
+ 
+static double rev180( double ang )
+/* Normalize angle to between +180 and -180 degrees */
+{
+    return  ang  -  360.0 * floor(ang*(1.0/360.0) + 0.5);
+}  /* rev180 */
+ 
+ 
+ 
+static double kepler( double m, double ex )
+/*
+ * Solves Kepler's equation
+ *  m      = mean anomaly
+ *  ex     = eccentricity
+ *  kepler = eccentric anomaly
+ */
+{
+    double m1, sinm, cosm, exd, exan, dexan, lim1, adko, adk, denom;
+    int converged;
+ 
+    m1 = rev180(m);
+    sinm = sind(m1);
+    cosm = cosd(m1);
+    /* 1st approximation: */
+    exan = atan2d(sinm,cosm-ex);
+    if ( ex > 0.008 )
+    { /* Iteration formula: */
+        exd = ex * RADEG;
+        lim1 = 1E-3 / ex;
+        adko = INFINITY;
+        denom = 1.0 - ex * cosd(exan);
+        do
+        {
+            dexan = (m1 + exd * sind(exan) - exan) / denom;
+            exan = exan + dexan;
+            adk = fabs(dexan);
+            converged = adk < EPSILON  ||  adk >= adko ;
+            adko = adk;
+            if ( !converged  &&  adk > lim1 )
+                denom = 1.0 - ex * cosd(exan);
+        } while ( !converged );
+    }
+    return  exan;
+}  /* kepler */
+ 
+ 
+static void vr( double *v, double *r, double m, double e, double a )
+/*
+ * Elliptic orbits only:
+ * computes: v = true anomaly   (degrees)
+ *           r = radius vector  (a.u.)
+ *   from:   m = mean anomaly   (degrees)
+ *           e = eccentricity
+ *           a = semimajor axis (a.u.)
+ */
+{
+    double ean, x, y;
+ 
+    ean = kepler(m,e);
+    x = a*(cosd(ean)-e);
+    y = a*sqrt(1.-e*e)*sind(ean);
+    *r = sqrt(x*x+y*y);
+    *v = atan2d(y,x);
+}  /* vr */
+ 
+ 
+void vrc( double *v, double *r, double tp, double e, double q )
+/*
+ * Elliptic, hyperbolic and near-parabolic orbits:
+ * computes: v  = true anomaly  (degrees)
+ *           r  = radius vector (a.u.)
+ *   from:   tp = time from perihelion (days)
+ *           e  = eccentricity
+ *           q  = perihelion distance (a.u.)
+ */
+{
+ 
+    double lambda;
+ 
+    double a, b, w, w2, w4, c, c1, c2, c3, c5, a0, a1, a2,
+           a3, m, n, g, adgg, adgg2, gs, dg;
+ 
+    if ( tp == 0.0 )  /* In perihelion */
+    {
+        *v = 0.0;
+        *r = q;
+        return;
+    }
+ 
+ 
+    lambda = (1.0-e) / (1.0+e);
+ 
+    if ( fabs(lambda) < 0.01 )
+    {  /* Near-parabolic orbits */
+        a = K2 * sqrt((1.0+e)/(q*q*q)) * tp;
+        b = sqrt( 1.0 + 2.25*a*a );
+        w = cubroot( b + 1.5*a ) - cubroot( b - 1.5*a );
+ 
+        /* Test if it's accuate enough to compute this as a near-parabolic orbit */
+        if ( fabs(w*w*lambda) > 0.2 )
+        {
+            if ( fabs(lambda) < 0.0002 )
+            {
+                /* Sorry, but we cannot compute this at all -- we must give up!
+                 *
+                 * This happens very rarely, in orbits having an eccentricity
+                 * some 2% away from 1.0 AND if the body is very very far from
+                 * perihelion.  E.g. a Kreutz sun-grazing comet having
+                 * eccentricity near 0.98 or 1.02, and being outside
+                 * the orbit of Pluto.  For any reasonable orbit this will
+                 * never happen in practice.
+                 *
+                 * You might want to code a more graceful error exit here though.
+                 *
+                 */
+                printf( "\nNear-parabolic orbit: inaccurate result."
+                        "\n  e = %f, lambda = %f, w = %f", e, lambda, w );
+                exit(1);
+            }
+            else
+            {
+                /* We cannot compute this as a near-parabolic orbit, so let's
+                   compute it as an elliptic or hyperbolic orbit instead. */
+                goto ellipse_hyperbola;
+            }
+        }
+ 
+        /* Go ahead computing the near-parabolic case */
+        c = 1.0 + 1.0 / (w*w);
+        c1 = 1.0 / c;
+        c2 = c1*c1;
+        c3 = c1*c2;
+        c5 = c3*c2;
+        w2 = w*w;
+        w4 = w2*w2;
+        a0 = w;
+        a1 = 2.0 * w * (0.33333333 + 0.2*w2) * c1;
+        a2 = 0.2 * w * (7.0 + 0.14285714 * (33.0*w2+7.4*w4)) * c3;
+        a3 = 0.022857143 * (108.0 + 37.177777*w2 + 5.1111111*w4) * c5;
+        w = (( lambda * a3 + a2 ) * lambda + a1 ) * lambda + a0;
+        w2 = w*w;
+        *v = 2.0 * atand(w);
+        *r = q * (1+w2) / ( 1.0 + w2*lambda );
+        return;  /* Near-parabolic orbit */
+    }
+ 
+ 
+ellipse_hyperbola:
+ 
+    if ( lambda > 0.0 )
+    {   /* Elliptic orbit: */
+        a = q / (1.0-e);            /* Semi-major axis */
+        m = KD * tp / sqrt(a*a*a);  /* Mean Anomaly */
+        vr( v, r, m, e, a );        /* Solve Kepler's equation, etc */
+    }
+    else
+    {   /* Hyperbolic orbit: */
+        a = q / (e-1.0);            /* Semi-major axis */
+        n = K * tp / sqrt(a*a*a);   /* "Daily motion" */
+        g = n/e;
+        adgg = INFINITY;
+        do  
+        {
+            adgg2 = adgg;
+            gs = sqrt(g*g+1.0);
+            dg = -( e*g - log(g+gs) - n ) / ( e - 1.0/gs );
+            g = g + dg;
+            adgg = fabs(dg/g);
+        } while ( adgg < adgg2  &&  adgg > 1E-5 );
+        gs = sqrt(g*g+1.0);
+        *v = 2.0 * atand( sqrt( (e+1.0)/(e-1.0) ) * g / (gs+1.0) );
+        *r = q * (1.0+e) / ( 1.0 + e*cosd(*v) );
+    }
+ 
+} /* vrc */
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: twobody.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.1 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/utc_gst.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/utc_gst.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/utc_gst.c	(revision 1719)
@@ -100,3 +100,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: utc_gst.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: utc_gst.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/vector.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/vector.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/vector.h	(revision 1719)
@@ -2,5 +2,5 @@
 #define __SATVECTOR_H
 
-/* $Id: vector.h,v 1.1.1.1 2001-04-10 14:40:47 cmv Exp $ */
+/* $Id: vector.h,v 1.2 2001-10-22 12:08:28 cmv Exp $ */
 
 #define dotp(A,B) ((A).x*(B).x+(A).y*(B).y+(A).z*(B).z)
@@ -16,4 +16,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: vector.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: vector.h,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/vsop87.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/vsop87.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/vsop87.c	(revision 1719)
@@ -152,6 +152,5 @@
 
 	    /* precision threshold */
-	    if(alpha>0) p = t_abs[alpha-1]; else p=0.;
-	    p = q/(t_abs[alpha] + alpha * p * 1e-4 + 1e-35);
+	    p= alpha ? q/(t_abs[alpha] + alpha*t_abs[alpha-1]*1e-4 + 1e-35) : q;
 #if VSOP_SPHERICAL
 	    if (cooidx == 2)	/* scale by semimajor axis for radius */
@@ -212,3 +211,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: vsop87.c,v $ $Date: 2001-10-11 12:40:41 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: vsop87.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.3 $ $Name: not supported by cvs2svn $"};
Index: trunk/SophyaExt/XephemAstroLib/vsop87.h
===================================================================
--- trunk/SophyaExt/XephemAstroLib/vsop87.h	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/vsop87.h	(revision 1719)
@@ -90,4 +90,4 @@
 
 /* For RCS Only -- Do Not Edit
- * @(#) $RCSfile: vsop87.h,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $
+ * @(#) $RCSfile: vsop87.h,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $
  */
Index: trunk/SophyaExt/XephemAstroLib/vsop87_data.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/vsop87_data.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/vsop87_data.c	(revision 1719)
@@ -6986,3 +6986,3 @@
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: vsop87_data.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: vsop87_data.c,v $ $Date: 2001-10-22 12:08:28 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};

Index: trunk/SophyaExt/XephemAstroLib/plans.c
===================================================================
--- trunk/SophyaExt/XephemAstroLib/plans.c	(revision 1717)
+++ trunk/SophyaExt/XephemAstroLib/plans.c	(revision 1719)
@@ -108,14 +108,20 @@
  * [planet][0] = angular size at 1 AU
  * [planet][1] = magnitude at 1 AU from sun and earth and 0 deg phase angle
- */
-static double vis_elements[8][2] = {
-	/* Mercury */	{ 6.74, -0.42, },
-	/* Venus */	{ 16.92, -4.34, },
-	/* Mars */	{ 9.36, -1.20, },
-	/* Jupiter */	{ 196.74, -9.4, },
-	/* Saturn */	{ 165.6, -8.88, },
-	/* Uranus */	{ 65.8, -7.19, },
-	/* Neptune */	{ 62.2, -6.87, },
-	/* Pluto */	{ 8.2, -1.0, }
+ * [planet][2] = A
+ * [planet][3] = B
+ * [planet][4] = C
+ *   where mag correction = A*(i/100) + B*(i/100)^2 + C*(i/100)^3
+ *      i = angle between sun and earth from planet, degrees
+ * from Explanatory Supplement, 1992
+ */
+static double vis_elements[8][5] = {
+	/* Mercury */	{ 6.74, -0.36, 3.8, -2.73, 2.00},
+	/* Venus */	{ 16.92, -4.29, 0.09, 2.39, -.65},
+	/* Mars */	{ 9.36, -1.52, 1.60, 0., 0.},
+	/* Jupiter */	{ 196.74, -9.25, 0.50, 0., 0.},
+	/* Saturn */	{ 165.6, -8.88, 4.40, 0., 0.},
+	/* Uranus */	{ 65.8, -7.19, 0.28, 0., 0.},
+	/* Neptune */	{ 62.2, -6.87, 0., 0., 0.},
+	/* Pluto */	{ 8.2, -1.01, 4.1, 0., 0.}
 };
 
@@ -132,5 +138,5 @@
  *	   seen from the center of the Earth for the given instant.
  *   dia:  angular diameter in arcsec at 1 AU, 
- *   mag:  visual magnitude when 1 AU from sun and earth at 0 phase angle.
+ *   mag:  visual magnitude
  *
  * all angles are in radians, all distances in AU.
@@ -148,9 +154,11 @@
 {
 	static double lastmjd = -10000;
-	static double lsn, bsn, rsn;	/* geometric geocentric coords of sun */
-	static double xsn, ysn, zsn;
+	static double lsn, bsn, rsn;	/* geocentric coords of sun */
+	static double xsn, ysn, zsn;	/* cartesian " */
 	double lp, bp, rp;		/* heliocentric coords of planet */
 	double xp, yp, zp, rho;		/* rect. coords and geocentric dist. */
 	double dt;			/* light time */
+	double *vp;			/* vis_elements[p] */
+	double ci, i;			/* sun/earth angle: cos, degrees */
 	int pass;
 
@@ -202,8 +210,25 @@
 	}
 
-	*dia = vis_elements[p][0];
-	*mag = vis_elements[p][1];
+	vp = vis_elements[p];
+	*dia = vp[0];
+
+	/* solve plane triangle, assume sun/earth dist == 1 */
+	ci = (rp*rp + rho*rho - 1)/(2*rp*rho);
+
+	/* expl supp equation for mag */
+	if (ci < -1) ci = -1;
+	if (ci >  1) ci =  1;
+	i = raddeg(acos(ci))/100.;
+	*mag = vp[1] + 5*log10(rho*rp) + i*(vp[2] + i*(vp[3] + i*vp[4]));
+
+	/* rings contribution if SATURN */
+	if (p == SATURN) {
+	    double et, st, set;
+	    satrings (bp, lp, rp, lsn+PI, rsn, mjd+MJD0, &et, &st);
+	    set = sin(fabs(et));
+	    *mag += (-2.60 + 1.25*set)*set;
+	}
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: plans.c,v $ $Date: 2001-04-10 14:40:47 $ $Revision: 1.1.1.1 $ $Name: not supported by cvs2svn $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: plans.c,v $ $Date: 2001-10-22 12:08:27 $ $Revision: 1.2 $ $Name: not supported by cvs2svn $"};